@@ -1363,7 +1363,7 @@ XLALSimIMREOBNRv2Generator(
   t = m * (dynamics->data[hiSRndx] + timePeak - dynamics->data[startIdx]);
   gsl_spline_init( spline, dynamicsHi->data, phiVecHi.data, retLen );
   /* sSub = phiVecHi.data[peakIdx] - phiC/2.; */
-  sSub = gsl_spline_eval( spline, timePeak, acc ) - phiC;
+  sSub = 0*gsl_spline_eval( spline, timePeak, acc ) - phiC;
 
   gsl_spline_free( spline );
   gsl_interp_accel_free( acc );
@@ -1424,6 +1424,7 @@ XLALSimIMREOBNRv2Generator(
      /* If we have an equal mass system, some modes will be zero */
      if ( eta == 0.25 && modeM % 2 )
      {
+       XLALDestroyCOMPLEX16TimeSeries( sigMode );
        continue;
      }
 
