@@ -76,6 +76,29 @@ tagSpinEOBHCoeffs
 }
 SpinEOBHCoeffs;
 
+typedef struct
+tagSEOBHCoeffConstants
+{
+
+  double a0k2; //Coefficient of a^0 in k2
+  double a1k2; //Coefficient of a^1 in k2
+
+  double a0k3; //Coefficient of a^0 in k3
+  double a1k3; //Coefficient of a^1 in k3
+
+  double a0k4; //Coefficient of a^0 in k4
+  double a1k4; //Coefficient of a^1 in k4
+  double a2k4; //Coefficient of a^2 in k4
+
+  double a0k5; //Coefficient of a^0 in k5
+  double a1k5; //Coefficient of a^1 in k5
+  double a2k5; //Coefficient of a^2 in k5
+
+}
+SEOBHCoeffConstants;
+
+SEOBHCoeffConstants XLALEOBSpinPrecCalcSEOBHCoeffConstants(REAL8 eta);
+
 /**
  * Parameters for the spinning EOB model.
  * 1) eobParams contains parameters common to nonspin and spin EOBNR models,
@@ -93,6 +116,7 @@ tagSpinEOBParams
 {
   EOBParams               *eobParams;
   SpinEOBHCoeffs          *seobCoeffs;
+  SEOBHCoeffConstants     *seobCoeffConsts;
   EOBNonQCCoeffs          *nqcCoeffs;
   REAL8Vector             *s1Vec;
   REAL8Vector             *s2Vec;
@@ -103,8 +127,9 @@ tagSpinEOBParams
   REAL8                   chi2;
   REAL8                   prev_dr;
   int                     alignedSpins;
+  Approximant             seobApproximant; /*OPTV3*/
   int                     tortoise;
-  int ignoreflux;
+  int                     ignoreflux;
 }
 SpinEOBParams;
 
@@ -126,6 +151,7 @@ struct tagHcapSphDeriv2Params
   SpinEOBParams   *params;
   UINT4           varyParam1;
   UINT4           varyParam2;
+  INT4            use_optimized;
 }
 HcapSphDeriv2Params;
 
