@@ -1,5 +1,7 @@
 /*
-*  Copyright (C) 2010 Craig Robinson, Yi Pan
+*  Copyright (C) 2010 Craig Robinson, Yi Pan, 2016 Zachariah Etienne,
+*                                                  Caleb Devine
+*                                                  David N. Buch
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -18,16 +20,6 @@
 */
 
 
-/**
- * \author Craig Robinson, Yi Pan
- *
- * \brief In newer versions of the EOBNR approximant, we
- * do not have an analytic expression for the derivative of the waveform.
- * As such, it is necessary to calculate the derivatives numerically. This
- * function provides the means to do just that.
- *
- */
-
 #ifndef _LALSIMIMRSPINEOBHCAPEXACTDERIVATIVE_C
 #define _LALSIMIMRSPINEOBHCAPEXACTDERIVATIVE_C
 
@@ -45,9 +37,8 @@
 #include "LALSimIMRSpinEOB.h"
 
 #include "LALSimIMRSpinEOBAuxFuncs.c"
-#include "LALSimIMRSpinEOBHamiltonianOptimized.c"
+//#include "LALSimIMRSpinEOBHamiltonianOptimized.c"
 
-//int UsePrec = 1;
 
 /*------------------------------------------------------------------------------------------
  *
@@ -57,8 +48,6 @@
  */
 
 
-//static REAL8 GSLSpinHamiltonianWrapperOptimized( REAL8 x, void *params );
-
 static REAL8 XLALSpinHcapExactDerivWRTParam(
                        const INT4 paramIdx,
                        const REAL8 values[],
@@ -102,7 +91,7 @@ static REAL8 XLALSimIMRSpinEOBHamiltonian_derivs_allatonce(
 							   );
 /*------------------------------------------------------------------------------------------
  *
- *          Defintions of functions.
+ *          Definitions of functions.
  *
  *------------------------------------------------------------------------------------------
  */
@@ -290,12 +279,12 @@ static REAL8 XLALSimIMRSpinEOBHamiltonian_ExactDeriv(
     case 4:
       {
 #include "mathematica_codes/SEOBNRv2_opt_pdata1tortoise.h"
-	return Hreal;
+	return Hreal; /* Returns dH/dpy */
       }
       break;
     default:
       {
-	printf("Option not supported: %d!\n",which_to_vary); exit(1);
+	printf("XLALSimIMRSpinEOBHamiltonian_ExactDeriv(): Derivative option not supported: %d!\n",which_to_vary); exit(1);
 	break;
       }
     }
@@ -304,12 +293,12 @@ static REAL8 XLALSimIMRSpinEOBHamiltonian_ExactDeriv(
     case 4:
       {
 #include "mathematica_codes/SEOBNRv2_opt_pdata1.h"
-	return Hreal;
+	return Hreal; /* Returns dH/dpy */
       }
       break;
     default:
       {
-	printf("Option not supported: %d!\n",which_to_vary); exit(1);
+	printf("XLALSimIMRSpinEOBHamiltonian_ExactDeriv(): Derivative option not supported: %d!\n",which_to_vary); exit(1);
 	break;
       }
     }
