@@ -15,6 +15,8 @@
 #include "LALSimIMRSpinEOBHamiltonianPrec.c"
 #include "LALSimIMREOBFactorizedWaveform.c"
 
+#include "LALSimIMRSpinEOBHcapExactDerivativePrec_v3opt.c"
+
 #ifndef _LALSIMIMRSPINPRECEOBINITIALCONDITIONS_C
 #define _LALSIMIMRSPINPRECEOBINITIALCONDITIONS_C
 
@@ -293,14 +295,15 @@ CartesianToSphericalPrec(
  */
 static int
 XLALFindSphericalOrbitPrec(
-          const gsl_vector * x,	/**<< Parameters requested by gsl root finder */
-		      void *params,	        /**<< Spin EOB parameters */
-		      gsl_vector * f	      /**<< Function values for the given parameters*/
+                           const gsl_vector * x,	/**<< Parameters requested by gsl root finder */
+                           void *params,	        /**<< Spin EOB parameters */
+                           gsl_vector * f	      /**<< Function values for the given parameters*/
 )
 {
 	int		debugPK = 0;
 	SEOBRootParams *rootParams = (SEOBRootParams *) params;
 	REAL8		mTotal = rootParams->params->eobParams->m1 + rootParams->params->eobParams->m2;
+        INT4            use_optimized = rootParams->use_optimized; // david added. make sure to change SEOBRootParams structure in other file when you move changes to lalsimulation/src
 	if (debugPK)
 		XLAL_PRINT_INFO("\n\nmtotal in XLALFindSphericalOrbitPrec = %f\n", (float)mTotal);
 
@@ -348,7 +351,11 @@ XLALFindSphericalOrbitPrec(
 	}
     UINT4 oldignoreflux = rootParams->params->ignoreflux;
     rootParams->params->ignoreflux = 1;
-	status = XLALSpinPrecHcapNumericalDerivative(0, rootParams->values, tmpDValues, rootParams->params);
+    if (0 /*use_optimized*/) { //david's: using numerical derivative until XLALSpinPrecHcapExactDerivative is fixed
+      status = XLALSpinPrecHcapExactDerivative(0, rootParams->values, tmpDValues, rootParams->params);
+    } else {
+      status = XLALSpinPrecHcapNumericalDerivative(0, rootParams->values, tmpDValues, rootParams->params);
+    }
     rootParams->params->ignoreflux = oldignoreflux;
 	for (int i = 0; i < 3; i++) {
 		rootParams->values[i + 6] *= mTotal * mTotal;
@@ -388,17 +395,24 @@ XLALFindSphericalOrbitPrec(
 		//rootParams->values[7] = 0.;
 		//rootParams->values[8] = sqrt(CalculateDotProductPrec(chi1vec, chi1vec));
     //rootParams->values[9] = 0.;
-		//rootParams->values[10]= 0.;
-		//rootParams->values[11]= sqrt(CalculateDotProductPrec(chi2vec, chi2vec));
-
-		dHdx = XLALSpinPrecHcapNumDerivWRTParam(0,
-                  rootParams->values, rootParams->params);
-		dHdpy = XLALSpinPrecHcapNumDerivWRTParam(4,
-                  rootParams->values, rootParams->params);
-		dHdpz = XLALSpinPrecHcapNumDerivWRTParam(5,
-                  rootParams->values, rootParams->params);
-	}
-
+    //rootParams->values[10]= 0.;
+    //rootParams->values[11]= sqrt(CalculateDotProductPrec(chi2vec, chi2vec));
+    if (use_optimized) {
+      dHdx = XLALSpinPrecHcapExactDerivWRTParam(0,
+                                                rootParams->values, rootParams->params);
+      dHdpy = XLALSpinPrecHcapExactDerivWRTParam(4,
+                                                 rootParams->values, rootParams->params);
+      dHdpz = XLALSpinPrecHcapExactDerivWRTParam(5,
+                                                 rootParams->values, rootParams->params);
+    } else {
+      dHdx = XLALSpinPrecHcapNumDerivWRTParam(0,
+                                              rootParams->values, rootParams->params);
+      dHdpy = XLALSpinPrecHcapNumDerivWRTParam(4,
+                                               rootParams->values, rootParams->params);
+      dHdpz = XLALSpinPrecHcapNumDerivWRTParam(5,
+                                               rootParams->values, rootParams->params);
+    }
+  }
 	if (XLAL_IS_REAL8_FAIL_NAN(dHdx)) { XLAL_ERROR(XLAL_EDOM); }
 	if (XLAL_IS_REAL8_FAIL_NAN(dHdpy)) { XLAL_ERROR(XLAL_EDOM); }
 	if (XLAL_IS_REAL8_FAIL_NAN(dHdpz)) { XLAL_ERROR(XLAL_EDOM); }
@@ -438,12 +452,13 @@ XLALFindSphericalOrbitPrec(
  */
 static double
 GSLSpinHamiltonianDerivWrapperPrec(double x,	/**<< Derivative at x */
-			       void *params /**<< Function parameters */ )
+                                   void *params /**<< Function parameters */
+)
 {
 	int		debugPK = 0;
 	HcapSphDeriv2Params *dParams = (HcapSphDeriv2Params *) params;
 	REAL8		mTotal = dParams->params->eobParams->m1 + dParams->params->eobParams->m2;
-
+        INT4            use_optimized = dParams->use_optimized;
 	REAL8		sphValues[12];
 	REAL8		cartValues[12];
 
@@ -469,7 +484,11 @@ GSLSpinHamiltonianDerivWrapperPrec(double x,	/**<< Derivative at x */
 	}
     UINT4 oldignoreflux = dParams->params->ignoreflux;
     dParams->params->ignoreflux = 1;
-	status = XLALSpinPrecHcapNumericalDerivative(0, cartValues, tmpDValues, dParams->params);
+    if(0 /*use_optimized*/) { //david's: using numerical derivative until XLALSpinPrecHcapExactDerivative is fixed
+      status = XLALSpinPrecHcapExactDerivative(0, cartValues, tmpDValues, dParams->params);
+    } else {
+      status = XLALSpinPrecHcapNumericalDerivative(0, cartValues, tmpDValues, dParams->params);
+    }
     dParams->params->ignoreflux = oldignoreflux;
 	for (int i = 0; i < 3; i++) {
 		cartValues[i + 6] *= mTotal * mTotal;
@@ -527,10 +546,15 @@ GSLSpinHamiltonianDerivWrapperPrec(double x,	/**<< Derivative at x */
 		switch (dParams->varyParam2) {
 		case 0:
 			/* dHdr */
+                  if(use_optimized) {
+			dHdx = XLALSpinPrecHcapExactDerivWRTParam(0, cartValues, dParams->params);
+			dHdpy = XLALSpinPrecHcapExactDerivWRTParam(4, cartValues, dParams->params);
+			dHdpz = XLALSpinPrecHcapExactDerivWRTParam(5, cartValues, dParams->params);
+                  } else {
 			dHdx = XLALSpinPrecHcapNumDerivWRTParam(0, cartValues, dParams->params);
 			dHdpy = XLALSpinPrecHcapNumDerivWRTParam(4, cartValues, dParams->params);
 			dHdpz = XLALSpinPrecHcapNumDerivWRTParam(5, cartValues, dParams->params);
-
+                  }
 			dHdr = dHdx - dHdpy * pphi / (r * r) + dHdpz * ptheta / (r * r);
 			//XLAL_PRINT_INFO("dHdr = %.16e\n", dHdr);
 			return dHdr;
@@ -538,12 +562,20 @@ GSLSpinHamiltonianDerivWrapperPrec(double x,	/**<< Derivative at x */
 			break;
 		case 4:
 			/* dHdptheta */
-			dHdpz = XLALSpinPrecHcapNumDerivWRTParam(5, cartValues, dParams->params);
+                  if(use_optimized){
+                    dHdpz = XLALSpinPrecHcapExactDerivWRTParam(5, cartValues, dParams->params);
+                  } else {
+                    dHdpz = XLALSpinPrecHcapNumDerivWRTParam(5, cartValues, dParams->params);
+                  }
 			return -dHdpz / r;
 			break;
 		case 5:
 			/* dHdpphi */
-			dHdpy = XLALSpinPrecHcapNumDerivWRTParam(4, cartValues, dParams->params);
+                  if (use_optimized) {
+                    dHdpy = XLALSpinPrecHcapExactDerivWRTParam(4, cartValues, dParams->params);
+                  } else {
+		    dHdpy = XLALSpinPrecHcapNumDerivWRTParam(4, cartValues, dParams->params);
+                  }
 			return dHdpy / r;
 			break;
 		default:
@@ -563,7 +595,8 @@ XLALCalculateSphHamiltonianDeriv2Prec(
 				  const int idx1,	/**<< Derivative w.r.t. index 1 */
 				  const int idx2,	/**<< Derivative w.r.t. index 2 */
 				  const REAL8 values[],	/**<< Dynamical variables in spherical coordinates */
-				  SpinEOBParams * params	/**<< Spin EOB Parameters */
+				  SpinEOBParams * params,	/**<< Spin EOB Parameters */
+                                  INT4 use_optimized    /**<< use_optimized=1 -> use EXACT instead of finite difference derivatives... UNSUPPORTED AT MOMENT. */
 )
 {
 
@@ -581,6 +614,7 @@ XLALCalculateSphHamiltonianDeriv2Prec(
 	dParams.varyParam1 = idx1;
 	dParams.varyParam2 = idx2;
 	dParams.params = params;
+        dParams.use_optimized = use_optimized;
 
 	/*
 	 * XLAL_PRINT_INFO( " In second deriv function: values\n" ); for ( int i = 0;
@@ -657,7 +691,8 @@ XLALSimIMRSpinEOBInitialConditionsPrec(
 				   const REAL8 inc,	/**<< Inclination */
 				   const REAL8 spin1[],	/**<< Initial spin vector 1 */
 				   const REAL8 spin2[],	/**<< Initial spin vector 2 */
-				   SpinEOBParams * params	/**<< Spin EOB parameters */
+				   SpinEOBParams * params,	/**<< Spin EOB parameters */
+                                   INT4 use_optimized /**<< use_optimized=1 -> use EXACT instead of finite difference derivatives, where needed */
 )
 {
 
@@ -884,6 +919,9 @@ XLALSimIMRSpinEOBInitialConditionsPrec(
 	rootFunction.n = 3;
 	rootFunction.params = &rootParams;
 
+        /* Set to use optimized or unoptimized code */
+        rootParams.use_optimized = use_optimized; // david added
+
 	/* Calculate the initial velocity from the given initial frequency */
 	omega = LAL_PI * mTotal * LAL_MTSUN_SI * fMin;
 	v0 = cbrt(omega);
@@ -1127,8 +1165,8 @@ XLALSimIMRSpinEOBInitialConditionsPrec(
 	REAL8		dHdpphi , d2Hdr2, d2Hdrdpphi;
 	REAL8		rDot    , dHdpr, flux, dEdr;
 
-	d2Hdr2 = XLALCalculateSphHamiltonianDeriv2Prec(0, 0, sphValues, params);
-	d2Hdrdpphi = XLALCalculateSphHamiltonianDeriv2Prec(0, 5, sphValues, params);
+	d2Hdr2 = XLALCalculateSphHamiltonianDeriv2Prec(0, 0, sphValues, params, use_optimized);
+	d2Hdrdpphi = XLALCalculateSphHamiltonianDeriv2Prec(0, 5, sphValues, params, use_optimized);
 
 	if (printPK)
 		XLAL_PRINT_INFO("d2Hdr2 = %.16e, d2Hdrdpphi = %.16e\n", d2Hdr2, d2Hdrdpphi);
@@ -1143,7 +1181,7 @@ XLALSimIMRSpinEOBInitialConditionsPrec(
 	}
     UINT4 oldignoreflux = params->ignoreflux;
     params->ignoreflux = 1;
-	status = XLALSpinPrecHcapNumericalDerivative(0, cartValues, tmpDValues, params);
+        status = XLALSpinPrecHcapNumericalDerivative(0, cartValues, tmpDValues, params); //david's: both v3 and v3_opt using numerical derivative until XLALSpinPrecHcapExactDerivative is fixed
     params->ignoreflux = oldignoreflux;
 	for (i = 0; i < 3; i++) {
 		cartValues[i + 6] *= mTotal * mTotal;
@@ -1218,8 +1256,11 @@ XLALSimIMRSpinEOBInitialConditionsPrec(
 		memcpy(cartData + 9, tmpS2Norm, 3 * sizeof(REAL8));
 
 		//XLAL_PRINT_INFO("Stas: starting FLux calculations\n");
-
-		flux = XLALInspiralPrecSpinFactorizedFlux(&polarDynamics, &cartDynamics, nqcCoeffs, omega, params, ham, lMax, SpinAlignedEOBversion);
+                if(use_optimized) {
+                  flux = XLALInspiralPrecSpinFactorizedFlux_exact(&polarDynamics, &cartDynamics, nqcCoeffs, omega, params, ham, lMax, SpinAlignedEOBversion);
+                } else {
+                  flux = XLALInspiralPrecSpinFactorizedFlux(&polarDynamics, &cartDynamics, nqcCoeffs, omega, params, ham, lMax, SpinAlignedEOBversion);
+                }
 		/*
 		 * flux  = XLALInspiralSpinFactorizedFlux( &polarDynamics,
 		 * nqcCoeffs, omega, params, ham, lMax, SpinAlignedEOBversion
@@ -1248,7 +1289,7 @@ XLALSimIMRSpinEOBInitialConditionsPrec(
         oldignoreflux = params->ignoreflux;
         params->ignoreflux = 1;
         params->seobCoeffs->updateHCoeffs = 1;
-		status = XLALSpinPrecHcapNumericalDerivative(0, cartValues, tmpDValues, params);
+		status = XLALSpinPrecHcapNumericalDerivative(0, cartValues, tmpDValues, params); //david's: both v3 and v3_opt using numerical derivative until XLALSpinPrecHcapExactDerivative is fixed
         params->ignoreflux = oldignoreflux;
 		for (i = 0; i < 3; i++) {
 			cartValues[i + 6] *= mTotal * mTotal;
