@@ -36,6 +36,13 @@
  * templates for compact binary inspiral signals in gravitational-wave
  * detectors", Phys. Rev. D 80, 084043 (2009), arXiv:0907.0700v1
  * For the spin terms a good reference are (3.15) and (3.16) of 1303.7412
+ *
+ * In the latest version coefficients of the terms n.S and L.S are reported
+ * "Averaged" spin coefficients refer to the ones obtained by orbital averaging,
+ * i.e. by using
+ * n_i n_j = 1/2 (\f$\delta_{ij} - \hat LN_i \hat LN_j\f$)
+ * However such orbital averaging at 2PN would introduce corrections
+ * at 3PN, as LNh is not constant.
  */
 
 static REAL8 UNUSED
@@ -100,37 +107,79 @@ XLALSimInspiralPNEnergy_3PNSOCoeff(
 /*  Eq. (6) of arXiv:astro-ph/0504538v2
  */
 static REAL8 UNUSED
-XLALSimInspiralPNEnergy_4PNS1S2Coeff(
+XLALSimInspiralPNEnergy_4PNS1S2CoeffAvg(
 	REAL8 eta)
 {
 	return 1./eta;
 }
 
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_4PNS1S2Coeff(
+	REAL8 eta)
+{
+	return -2./eta;
+}
+
 /*  Eq. (6) of arXiv:astro-ph/0504538v2
  */
 static REAL8 UNUSED
-XLALSimInspiralPNEnergy_4PNS1S2OCoeff(
+XLALSimInspiralPNEnergy_4PNS1S2OCoeffAvg(
 	REAL8 eta)
 {
 	return -3./eta;
 }
 
-/*  Eq. (6) of arXiv:astro-ph/0504538v2
- */
 static REAL8 UNUSED
-XLALSimInspiralPNEnergy_4PNQM2SCoeff(
-	REAL8 mByM)
+XLALSimInspiralPNEnergy_4PNS1S2OCoeff(
+	REAL8 UNUSED eta)
 {
-	return (1./mByM/mByM) / 2.;
+	return 0.;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_4PNS1S2nCoeff(
+	REAL8 UNUSED eta)
+{
+	return 6./eta;
 }
 
 /*  Eq. (6) of arXiv:astro-ph/0504538v2
  */
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_4PNQM2SCoeffAvg(
+	REAL8 mByM)
+{
+	return .5/mByM/mByM;
+}
+
+/*  Eq. (6) of arXiv:astro-ph/0504538v2
+ */
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_4PNQM2SOCoeffAvg(
+	REAL8 mByM)
+{
+	return -1.5/mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_4PNQM2SCoeff(
+	REAL8 mByM)
+{
+	return 2./mByM/mByM;
+}
+
 static REAL8 UNUSED
 XLALSimInspiralPNEnergy_4PNQM2SOCoeff(
 	REAL8 mByM)
 {
-	return -3. * (1./mByM/mByM) / 2.;
+	return -3./mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_4PNQM2SnCoeff(
+	REAL8 mByM)
+{
+	return -3./mByM/mByM;
 }
 
 /*  Eq. 4.6 of arXiv:1212.5520
@@ -148,7 +197,7 @@ static REAL8 UNUSED
 XLALSimInspiralPNEnergy_6PNS1S2Coeff(
 	REAL8 eta)
 {
-	return 2./eta-11./6.;
+	return -2./eta -1./3.;
 }
 
 /*  From (3.30) of arXiv:1501.01529
@@ -157,7 +206,14 @@ static REAL8 UNUSED
 XLALSimInspiralPNEnergy_6PNS1S2OCoeff(
 	REAL8 eta)
 {
-	return -11./3./eta + 2.3/1.8;
+	return 1./3./eta - 2./9.;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_6PNS1S2nCoeff(
+	REAL8 eta)
+{
+        return 8./eta - 3.;
 }
 
 /*  From (3.30) of arXiv:1501.01529
@@ -166,7 +222,7 @@ static REAL8 UNUSED
 XLALSimInspiralPNEnergy_6PNSelf2SCoeff(
 	REAL8 mByM)
 {
-	return -1./mByM/mByM - 1./6./mByM - 0.5;
+	return 4./mByM/mByM - 3./mByM - 1.;
 }
 
 /*  From (3.30) of arXiv:1501.01529
@@ -175,7 +231,14 @@ static REAL8 UNUSED
 XLALSimInspiralPNEnergy_6PNSelf2SOCoeff(
 	REAL8 mByM)
 {
-	return 6./mByM/mByM - 1.5/mByM - 1.1/1.8;
+	return 1./mByM/mByM + 4./3./mByM - 1./9.;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_6PNSelf2SnCoeff(
+	REAL8 mByM)
+{
+	return -10./mByM/mByM + 17./3./mByM + 1.;
 }
 
 /*  From (3.30) of arXiv:1501.01529
@@ -184,7 +247,7 @@ static REAL8 UNUSED
 XLALSimInspiralPNEnergy_6PNQM2SCoeff(
 	REAL8 mByM)
 {
-	return 1.25/mByM/mByM + 1.25/mByM + 5./12.;
+	return -1.5/mByM/mByM - 3.5/mByM - 5./6.;
 }
 
 /*  From (3.30) of arXiv:1501.01529
@@ -192,10 +255,24 @@ XLALSimInspiralPNEnergy_6PNQM2SCoeff(
 static REAL8 UNUSED
 XLALSimInspiralPNEnergy_6PNQM2SOCoeff(
 	REAL8 mByM)
+{
+	return -1./mByM/mByM + 1./mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_6PNQM2SOCoeffAvg(
+	REAL8 mByM)
 {
 	return -15./4./mByM/mByM - 15./4./mByM - 1.25;
 }
 
+static REAL8 UNUSED
+XLALSimInspiralPNEnergy_6PNQM2SnCoeff(
+	REAL8 mByM)
+{
+	return 5.5/mByM/mByM + 9.5/mByM + 2.5;
+}
+
 /*  Eq. (4.6) of arXiv:1212.5520
  *  Symbol definitions right above eq. (3.1)
  */
@@ -274,44 +351,107 @@ static REAL8 UNUSED
 XLALSimInspiralPNFlux_4PNS1S2Coeff(
     REAL8 eta)
 {
-    return -103./48./eta;
+    return 41./6./eta;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralPNFlux_4PNS1S2OCoeff(
     REAL8 eta)
+{
+    return -71./24./eta;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNS1S2nCoeff(
+    REAL8 eta)
+{
+    return -431./24./eta;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNS1S2CoeffAvg(
+    REAL8 eta)
+{
+    return -103./48./eta;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNS1S2OCoeffAvg(
+    REAL8 eta)
 {
     return 289./48./eta;
 }
 
-static REAL8 UNUSED
-XLALSimInspiralPNFlux_4PNQM2SCoeff(
-    REAL8 mByM)
-{
-    return -1./mByM/mByM;
-}
-
-static REAL8 UNUSED
-XLALSimInspiralPNFlux_4PNQM2SOCoeff(
-    REAL8 mByM)
-{
-    return 3./mByM/mByM;
-}
-
 static REAL8 UNUSED
 XLALSimInspiralPNFlux_4PNSelf2SCoeff(
     REAL8 mByM)
 {
-    return 7./96./mByM/mByM;
+    return 1./12./mByM/mByM;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralPNFlux_4PNSelf2SOCoeff(
     REAL8 mByM)
+{
+    return -1./48./mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNSelf2SnCoeff(
+    REAL8 mByM)
+{
+    return -1./48./mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNSelf2SCoeffAvg(
+    REAL8 mByM)
+{
+    return 7./96./mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNSelf2SOCoeffAvg(
+    REAL8 mByM)
 {
     return -1./96./mByM/mByM;
 }
 
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNQM2SCoeff(
+    REAL8 mByM)
+{
+    return 3.5/mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNQM2SOCoeff(
+    REAL8 mByM)
+{
+    return -1.5/mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNQM2SnCoeff(
+    REAL8 mByM)
+{
+    return -9./mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNQM2SCoeffAvg(
+    REAL8 mByM)
+{
+    return -1./mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_4PNQM2SOCoeffAvg(
+    REAL8 mByM)
+{
+    return 3./mByM/mByM;
+}
+
 static REAL8 UNUSED
 XLALSimInspiralPNFlux_5PNCoeff(
 	REAL8 eta)
@@ -360,42 +500,63 @@ static REAL8 UNUSED
 XLALSimInspiralPNFlux_6PNS1S2Coeff(
     REAL8 eta)
 {
-	return 212.3/8.4/eta + 82.1/7.2;
+	return -182.5/5.6/eta - 129.05/5.04;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralPNFlux_6PNS1S2OCoeff(
     REAL8 eta)
 {
-    return -56.47/1.68/eta - 202.3/7.2;
+    return 97./4./eta + 49.9/5.6;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_6PNS1S2nCoeff(
+    REAL8 eta)
+{
+    return 972.1/8.4/eta +  466.3/6.3;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralPNFlux_6PNSelf2SCoeff(
     REAL8 mByM)
 {
-    return 18.9/(1.6*mByM*mByM) - 3.5/(14.4*mByM) + 4.7/14.4;
+    return 5.87/(1.12*mByM*mByM) - 28.19/(5.04*mByM) + 1.9/100.8;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralPNFlux_6PNSelf2SOCoeff(
     REAL8 mByM)
 {
-    return -239./16./mByM/mByM + 293./144./mByM + 299./144.;
+    return -9.37/(1.12*mByM*mByM) + 18.61/(2.52*mByM) + 2.67/1.12;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_6PNSelf2SnCoeff(
+    REAL8 mByM)
+{
+    return 92./7./mByM/mByM + 53.93/5.04/mByM + 1.55/2.52;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralPNFlux_6PNQM2SCoeff(
     REAL8 mByM)
 {
-    return  2.79/(1.12*mByM*mByM) + 4.5/(1.6*mByM) - 43./8.;
+    return  -224.5/(8.4*mByM*mByM) + 3.73/(1.68*mByM) + 35.9/2.8;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralPNFlux_6PNQM2SOCoeff(
     REAL8 mByM)
 {
-    return  -8.37/(1.12*mByM*mByM) - 13.5/(1.6*mByM) + 129./8.;
+    return 36.53/(1.68*mByM*mByM) - 65.9/(8.4*mByM) - 2.9/1.4;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralPNFlux_6PNQM2SnCoeff(
+    REAL8 mByM)
+{
+    return  98.17/(1.68*mByM*mByM) + 1.99/(1.68*mByM) - 101.9/2.8;
 }
 
 /*
@@ -457,10 +618,7 @@ XLALSimInspiralPNPhasing_F2(
 	const REAL8 chi1sq,/**< Magnitude of dimensionless spin 1 */
 	const REAL8 chi2sq, /**< Magnitude of dimensionless spin 2 */
 	const REAL8 chi1dotchi2, /**< Dot product of dimensionles spin 1 and spin 2 */
-	const REAL8 qm_def1, /**< Quadrupole deformation parameter of body 1 (dimensionless) */
-	const REAL8 qm_def2, /**< Quadrupole deformation parameter of body 2 (dimensionless) */
-	const LALSimInspiralSpinOrder spinO, /**< Enums specifying spin order are in LALSimInspiralWaveformFlags.h */
-    const LALSimInspiralTestGRParam *p /**< Linked list containing the extra testing GR parameters >**/
+	LALDict *p /**< LAL dictionary containing accessory parameters */
 	)
 {
     const REAL8 mtot = m1 + m2;
@@ -501,19 +659,18 @@ XLALSimInspiralPNPhasing_F2(
                      + 378515.L/1512.L * eta - 74045.L/756.L * eta*eta);
 
     /* modify the PN coefficients if a non null LALSimInspiralTestGRParam structure is passed */
-    if (p!=NULL)
-    {
-      if (XLALSimInspiralTestGRParamExists(p,"dchi0")) pfa->v[0]*=(1.0+XLALSimInspiralGetTestGRParam(p,"dchi0"));
-      if (XLALSimInspiralTestGRParamExists(p,"dchi1")) pfa->v[1] = XLALSimInspiralGetTestGRParam(p,"dchi1");
-      if (XLALSimInspiralTestGRParamExists(p,"dchi2")) pfa->v[2]*=(1.0+XLALSimInspiralGetTestGRParam(p,"dchi2"));
-      if (XLALSimInspiralTestGRParamExists(p,"dchi3")) pfa->v[3]*=(1.0+XLALSimInspiralGetTestGRParam(p,"dchi3"));
-      if (XLALSimInspiralTestGRParamExists(p,"dchi4")) pfa->v[4]*=(1.0+XLALSimInspiralGetTestGRParam(p,"dchi4"));
-      if (XLALSimInspiralTestGRParamExists(p,"dchi5")) pfa->v[5]*=(1.0+XLALSimInspiralGetTestGRParam(p,"dchi5"));
-      if (XLALSimInspiralTestGRParamExists(p,"dchi5l")) pfa->vlogv[5]*=(1.0+XLALSimInspiralGetTestGRParam(p,"dchi5l"));
-      if (XLALSimInspiralTestGRParamExists(p,"dchi6")) pfa->v[6]*=(1.0+XLALSimInspiralGetTestGRParam(p,"dchi6"));
-      if (XLALSimInspiralTestGRParamExists(p,"dchi6l")) pfa->vlogv[6]*=(1.0+XLALSimInspiralGetTestGRParam(p,"dchi6l"));
-      if (XLALSimInspiralTestGRParamExists(p,"dchi7")) pfa->v[7]*=(1.0+XLALSimInspiralGetTestGRParam(p,"dchi7"));
-    }
+    pfa->v[0]*=(1.0+XLALSimInspiralWaveformParamsLookupNonGRDChi0(p));
+    pfa->v[1] = XLALSimInspiralWaveformParamsLookupNonGRDChi1(p);
+    pfa->v[2]*=(1.0+XLALSimInspiralWaveformParamsLookupNonGRDChi2(p));
+    pfa->v[3]*=(1.0+XLALSimInspiralWaveformParamsLookupNonGRDChi3(p));
+    pfa->v[4]*=(1.0+XLALSimInspiralWaveformParamsLookupNonGRDChi4(p));
+    pfa->v[5]*=(1.0+XLALSimInspiralWaveformParamsLookupNonGRDChi5(p));
+    pfa->vlogv[5]*=(1.0+XLALSimInspiralWaveformParamsLookupNonGRDChi5L(p));
+    pfa->v[6]*=(1.0+XLALSimInspiralWaveformParamsLookupNonGRDChi6(p));
+    pfa->vlogv[6]*=(1.0+XLALSimInspiralWaveformParamsLookupNonGRDChi6L(p));
+    pfa->v[7]*=(1.0+XLALSimInspiralWaveformParamsLookupNonGRDChi7(p));
+    REAL8 qm_def1=1.+XLALSimInspiralWaveformParamsLookupdQuadMon1(p);
+    REAL8 qm_def2=1.+XLALSimInspiralWaveformParamsLookupdQuadMon2(p);
     
     /* Compute 2.0PN SS, QM, and self-spin */
     // See Eq. (6.24) in arXiv:0810.5336
@@ -530,7 +687,7 @@ XLALSimInspiralPNPhasing_F2(
 
     /* Spin-orbit terms - can be derived from arXiv:1303.7412, Eq. 3.15-16 */
     const REAL8 pn_gamma = (554345.L/1134.L + 110.L*eta/9.L)*SL + (13915.L/84.L - 10.L*eta/3.L)*dSigmaL;
-    switch( spinO )
+    switch( XLALSimInspiralWaveformParamsLookupPNSpinOrder(p) )
     {
         case LAL_SIM_INSPIRAL_SPIN_ORDER_ALL:
         case LAL_SIM_INSPIRAL_SPIN_ORDER_35PN:
@@ -550,7 +707,7 @@ XLALSimInspiralPNPhasing_F2(
             break;
         default:
             XLALPrintError("XLAL Error - %s: Invalid spin PN order %i\n",
-                    __func__, spinO );
+			   __func__, XLALSimInspiralWaveformParamsLookupPNSpinOrder(p) );
             XLAL_ERROR_VOID(XLAL_EINVAL);
             break;
     }
@@ -758,6 +915,13 @@ XLALSimInspiralTaylorT2dtdv_7PNSOCoeff(
 static REAL8 UNUSED
 XLALSimInspiralTaylorT2dtdv_4PNS1S2Coeff(
     REAL8 eta)
+{
+    return -77./6./eta;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_4PNS1S2CoeffAvg(
+    REAL8 eta)
 {
     return 247./48./eta;
 }
@@ -765,13 +929,34 @@ XLALSimInspiralTaylorT2dtdv_4PNS1S2Coeff(
 static REAL8 UNUSED
 XLALSimInspiralTaylorT2dtdv_4PNS1S2OCoeff(
     REAL8 eta)
+{
+    return 71./24./eta;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_4PNS1S2OCoeffAvg(
+    REAL8 eta)
 {
     return -721./48./eta;
 }
 
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_4PNS1S2nCoeff(
+    REAL8 eta)
+{
+    return 863./24./eta;
+}
+
 static REAL8 UNUSED
 XLALSimInspiralTaylorT2dtdv_4PNSelf2SCoeff(
     REAL8 mByM)
+{
+    return -1./12./mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_4PNSelf2SCoeffAvg(
+    REAL8 mByM)
 {
     return - 7./96./mByM/mByM;
 }
@@ -779,20 +964,55 @@ XLALSimInspiralTaylorT2dtdv_4PNSelf2SCoeff(
 static REAL8 UNUSED
 XLALSimInspiralTaylorT2dtdv_4PNSelf2SOCoeff(
         REAL8 mByM)
+{
+    return 1./48./mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_4PNSelf2SOCoeffAvg(
+        REAL8 mByM)
 {
     return 1./96./mByM/mByM;
 }
 
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_4PNSelf2SnCoeff(
+        REAL8 mByM)
+{
+    return 1./48./mByM/mByM;
+}
+
 static REAL8 UNUSED
 XLALSimInspiralTaylorT2dtdv_4PNQM2SCoeff(
         REAL8 mByM)
 {
-        return 2.5/mByM/mByM;
+        return -6.5/mByM/mByM;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralTaylorT2dtdv_4PNQM2SOCoeff(
 	REAL8 mByM)
+{
+	return 1.5/mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_4PNQM2SnCoeff(
+	REAL8 mByM)
+{
+	return 18./mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_4PNQM2SCoeffAvg(
+        REAL8 mByM)
+{
+        return 2.5/mByM/mByM;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_4PNQM2SOCoeffAvg(
+	REAL8 mByM)
 {
 	return -7.5/mByM/mByM;
 }
@@ -811,6 +1031,13 @@ XLALSimInspiralTaylorT2dtdv_6PNSelf2SOCoeff(
     return 754.979/(16.128*mByM*mByM) + 15.43/2.88/mByM + 4.9/28.8;
 }
 
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_6PNSelf2SnCoeff(
+    REAL8 mByM)
+{
+    return -427.549/(8.064*mByM*mByM) + 12.181/1.008/mByM + 3.293/1.008;
+}
+
 static REAL8 UNUSED
 XLALSimInspiralTaylorT2dtdv_6PNS1S2Coeff(
     REAL8 eta)
@@ -825,13 +1052,6 @@ XLALSimInspiralTaylorT2dtdv_6PNS1S2OCoeff(
     return  -170.603/8.064/eta - 25.43/1.44;
 }
 
-static REAL8 UNUSED
-XLALSimInspiralTaylorT2dtdv_6PNQM2SOCoeff(
-    REAL8 mByM)
-{
-    return  -94.07/(2.24*mByM*mByM) -58.7/1.6/mByM + 9.;
-}
-
 static REAL8 UNUSED
 XLALSimInspiralTaylorT2dtdv_6PNQM2SCoeff(
     REAL8 mByM)
@@ -839,6 +1059,13 @@ XLALSimInspiralTaylorT2dtdv_6PNQM2SCoeff(
     return  94.07/(6.72*mByM*mByM) + 58.7/4.8/mByM - 3.;
 }
 
+static REAL8 UNUSED
+XLALSimInspiralTaylorT2dtdv_6PNQM2SOCoeff(
+    REAL8 mByM)
+{
+    return  -94.07/(2.24*mByM*mByM) -58.7/1.6/mByM + 9.;
+}
+
 static REAL8 UNUSED
 XLALSimInspiralTaylorT2dtdv_10PNTidalCoeff(
         REAL8 mByM)
@@ -1205,39 +1432,95 @@ XLALSimInspiralTaylorT4wdot_4PNCoeff(
 static REAL8 UNUSED
 XLALSimInspiralTaylorT4wdot_4PNS1S2Coeff(
 	REAL8 eta)
+{
+	return 77. / 6. / eta;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT4wdot_4PNS1S2CoeffAvg(
+	REAL8 eta)
 {
 	return - 247. / 48. / eta;
 }
 
 static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNS1S2OCoeff(
 	REAL8 eta)
+{
+	return -71. / 24. / eta;
+}
+
+static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNS1S2OCoeffAvg(
+	REAL8 eta)
 {
 	return 721. / 48. / eta;
 }
 
+static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNS1S2nCoeff(
+	REAL8 eta)
+{
+	return -863./24./eta;
+}
+
 static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNSelf2SCoeff(
         REAL8 mByM)
+{
+        return 1./12./mByM/mByM;
+}
+
+static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNSelf2SCoeffAvg(
+        REAL8 mByM)
 {
         return 7./96./mByM/mByM;
 }
 
 static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNSelf2SOCoeff(
         REAL8 mByM)
+{
+        return -1./48./mByM/mByM;
+}
+
+static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNSelf2SOCoeffAvg(
+        REAL8 mByM)
 {
         return -1./96./mByM/mByM;
 }
+
+static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNSelf2SnCoeff(
+        REAL8 mByM)
+{
+        return -1./48./mByM/mByM;
+}
+
 static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNQM2SCoeff(
         REAL8 mByM)
+{
+        return 6.5/mByM/mByM;
+}
+
+static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNQM2SCoeffAvg(
+        REAL8 mByM)
 {
         return -2.5/mByM/mByM;
 }
 
 static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNQM2SOCoeff(
         REAL8 mByM)
+{
+        return -1.5/mByM/mByM;
+}
+
+static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNQM2SOCoeffAvg(
+        REAL8 mByM)
 {
         return 7.5/mByM/mByM;
 }
 
+static REAL8 UNUSED XLALSimInspiralTaylorT4wdot_4PNQM2SnCoeff(
+        REAL8 mByM)
+{
+        return -18./mByM/mByM;
+}
+
 static REAL8 UNUSED
 XLALSimInspiralTaylorT4wdot_5PNCoeff(
 	REAL8 eta)
@@ -1290,42 +1573,63 @@ static REAL8 UNUSED
 XLALSimInspiralTaylorT4wdot_6PNS1S2Coeff(
 	REAL8 eta)
 {
-	return 108.79/(6.72*eta) + 75.25/2.88;
+	return -52.1/(2.8*eta) - 194.71/5.04;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralTaylorT4wdot_6PNS1S2OCoeff(
 	REAL8 eta)
 {
-	return 162.25/(2.24*eta) -129.31/2.88;
+	return 514.7/(4.8*eta) +20.021/1.008;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT4wdot_6PNS1S2nCoeff(
+	REAL8 eta)
+{
+	return 233.83/(3.36*eta) + 130.559/1.008;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralTaylorT4wdot_6PNSelf2SCoeff(
 	REAL8 mByM)
 {
-	return 101.9/(6.4*mByM*mByM) + 2.51/(5.76*mByM) + 13.33/5.76;
+	return -11.91/(1.12*mByM*mByM) + 8.09/(1.26*mByM) + 4.037/1.008;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralTaylorT4wdot_6PNSelf2SOCoeff(
 	REAL8 mByM)
 {
-	return -49.3/(6.4*mByM*mByM) + 197.47/(5.76*mByM) + 56.45/5.76;
+	return 42.23/(2.24*mByM*mByM) + 57.049/(2.016*mByM) + 16.349/2.016;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT4wdot_6PNSelf2SnCoeff(
+	REAL8 mByM)
+{
+	return 118.97/(2.24*mByM*mByM) -24.131/(2.016*mByM) - 6.817/2.016;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralTaylorT4wdot_6PNQM2SCoeff(
 	REAL8 mByM)
 {
-	return -6.59/(2.24*mByM*mByM) + 7.3/(4.8*mByM) - 43./4.;
+	return -59.17/(3.36*mByM*mByM) + 50.7/(5.6*mByM) + 65.3/2.8;
 }
 
 static REAL8 UNUSED
 XLALSimInspiralTaylorT4wdot_6PNQM2SOCoeff(
 	REAL8 mByM)
 {
-	return 19.77/(2.24*mByM*mByM) - 7.3/(1.6*mByM) + 129./4.;
+	return 39.47/(1.68*mByM*mByM) - 25.4/(2.1*mByM) - 5.1/2.8;
+}
+
+static REAL8 UNUSED
+XLALSimInspiralTaylorT4wdot_6PNQM2SnCoeff(
+	REAL8 mByM)
+{
+	return 98.57/(3.36*mByM*mByM) - 25.31/(1.68*mByM) -477./7.;
 }
 
 static REAL8 UNUSED
@@ -1428,18 +1732,18 @@ XLALSimInspiralLDot_3PNSOCoeff(
         return 0.5+1.5/mByM;
 }
 
+/* Using spin-self^2 derivatives at v^6 from
+ * eq. A.2 of Blanchet et al. 1501.01529
+ * and relating to LNh derivative through (4.25)
+ * of arXiv:0812.4413.
+ */
 static REAL8 UNUSED
-XLALSimInspiralLDot_4PNS1S2Coeff(
+XLALSimInspiralLDot_4PNS1S2CoeffAvg(
         REAL8 eta)
 {
         return -1.5/eta;
 }
 
-/* Using spin-self^2 derivatives at v^6 from
- * eq. 2.23 of Blanchet et al. 0812.4413
- * and relating to LNh derivative through (4.25)
- * of arXiv:0812.4413.
- */
 static REAL8 UNUSED
 XLALSimInspiralLDot_4PNQMSSCoeff(
         REAL8 mByM)
@@ -1459,33 +1763,6 @@ XLALSimInspiralLDot_5PNSOCoeff(
   return ( 9./8./mByM + 5./8 + 29./24.*mByM +mByM*mByM/24.);
 }
 
-/* See eq. (A2) of arXiv:1501.01529, see also notes in
- * https://bugs.ligo.org/redmine/issues/2xxx
- */
-static REAL8 UNUSED
-XLALSimInspiralLDot_6PNS1S2Coeff(
-        REAL8 mByM)
-{
-        return ( -0.5/(mByM*(1.-mByM))-mByM/(1.-mByM)-2./3.);
-}
-
-/* See eq. A.2 of arXiv:1501.01529
- */
-static REAL8 UNUSED
-XLALSimInspiralLDot_6PNS1S1Coeff(
-        REAL8 mByM)
-{
-  return ( 15./(4.*mByM*mByM) - 1./mByM -5./12.);
-}
-
-// See eq. (A2) of arXiv:1501.01529
-static REAL8 UNUSED
-XLALSimInspiralLDot_6PNQMSSCoeff(
-        REAL8 mByM)
-{
-        return -(2.25/(mByM*mByM) + 2.25/mByM + .75);
-}
-
 // See (3.4) of arXiv:1212.5520
 static REAL8 UNUSED
 XLALSimInspiralLDot_7PNSOCoeff(
@@ -1510,24 +1787,37 @@ XLALSimInspiralSpinDot_3PNCoeff(
 }
 
 /* S1S2 contribution
- * see. eq. 2.23 of arXiv:0812.4413
+ * see. eq. A.2 of arXiv:1501.01529
  */
 static const REAL8 UNUSED
-XLALSimInspiralSpinDot_4PNS2Coeff=0.5;
+XLALSimInspiralSpinDot_4PNS2Coeff=-1.;
 
 static const REAL8 UNUSED
-XLALSimInspiralSpinDot_4PNS2OCoeff=-1.5;
+XLALSimInspiralSpinDot_4PNS2nCoeff=3.;
+
+static const REAL8 UNUSED
+XLALSimInspiralSpinDot_4PNS2CoeffAvg=0.5;
+
+static const REAL8 UNUSED
+XLALSimInspiralSpinDot_4PNS2OCoeffAvg=-1.5;
 
 /* S1S1 contribution
- * again eq. 2.23 of arXiv:0812.4413
+ * again eq. A.2 of arXiv:1501.01529
  */
 static REAL8 UNUSED
-XLALSimInspiralSpinDot_4PNQMSOCoeff(
+XLALSimInspiralSpinDot_4PNQMSOCoeffAvg(
 	REAL8 mByM)
 {
 	return 1.5 * (1. - 1./mByM);
 }
 
+static REAL8 UNUSED
+XLALSimInspiralSpinDot_4PNQMSnCoeff(
+	REAL8 mByM)
+{
+	return 3 * (1./mByM - 1.);
+}
+
 /* dS1, 2.5PN
  * eq. 7.8 of Blanchet et al. gr-qc/0605140
  */
@@ -1538,38 +1828,6 @@ XLALSimInspiralSpinDot_5PNCoeff(
 	return 9./8. - mByM/2. + 7.*mByM*mByM/12. - 7.*mByM*mByM*mByM/6. - mByM*mByM*mByM*mByM/24.;
 }
 
-/* dS1, 3PN
- * eq. A1 of Bohe' et al. arXiv:1501.01529
- * See also https://bugs.ligo.org/redmine/issues/2xxx
- */
-static REAL8 UNUSED
-XLALSimInspiralSpinDot_6PNS1S2Coeff(
-       REAL8 mByM)
-{
-  return 0.5*mByM*mByM + 0.5*mByM;
-}
-
-static REAL8 UNUSED
-XLALSimInspiralSpinDot_6PNS1OCoeff(
-	REAL8 mByM)
-{
-	return 15./4./mByM - 19./4. + 7./12.*mByM + 5.*mByM*mByM/12.;
-}
-
-static REAL8 UNUSED
-XLALSimInspiralSpinDot_6PNS2OCoeff(
-	REAL8 mByM)
-{
-	return -0.5 - 2./3.*mByM - 1./3.*mByM*mByM;
-}
-
-static REAL8 UNUSED
-XLALSimInspiralSpinDot_6PNQMSOCoeff(
-	REAL8 mByM)
-{
-        return 0.75*mByM*mByM + 1.5*mByM -2.25/mByM;
-}
-
 /* dS1, 3.5PN
  * eq. 3.4 of Bohe' et al. arXiv:1212.5520
  */
