@@ -1,5 +1,6 @@
 /*
- * LALSimulationVCSInfo.h - LALSimulation VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALSimulationVCSInfo.h - LALSimulation VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALSIMULATION_NAME "LALSimulation"
-#define LALSIMULATION_VCS_ID "2caa475aa99f81c133c0d5047f4ad6f41d3f8064"
-#define LALSIMULATION_VCS_DATE "2016-10-10 17:31:35 +0000"
+/* VCS information */
+#define LALSIMULATION_VCS_ID "9eb4cb215be628d8881a42e2ab467e3883ffba73"
+#define LALSIMULATION_VCS_DATE "2017-03-16 13:48:56 +0000"
 #define LALSIMULATION_VCS_BRANCH "None"
-#define LALSIMULATION_VCS_TAG "lalsimulation-v1.6.1"
+#define LALSIMULATION_VCS_TAG "lalsimulation-v1.7.3"
 #define LALSIMULATION_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALSIMULATION_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALSIMULATION_VCS_CLEAN "CLEAN"
 #define LALSIMULATION_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALSIMULATION_VCS_IDENT_ID "$" "LALSimulationId: 2caa475aa99f81c133c0d5047f4ad6f41d3f8064 " "$"
-#define LALSIMULATION_VCS_IDENT_DATE "$" "LALSimulationDate: 2016-10-10 17:31:35 +0000 " "$"
-#define LALSIMULATION_VCS_IDENT_BRANCH "$" "LALSimulationBranch: None " "$"
-#define LALSIMULATION_VCS_IDENT_TAG "$" "LALSimulationTag: lalsimulation-v1.6.1 " "$"
-#define LALSIMULATION_VCS_IDENT_AUTHOR "$" "LALSimulationAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALSIMULATION_VCS_IDENT_COMMITTER "$" "LALSimulationCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALSIMULATION_VCS_IDENT_STATUS "$" "LALSimulationStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalSimulationVCSInfoHeader = { \
-  LALSIMULATION_NAME, \
-  LALSIMULATION_VERSION, \
-  LALSIMULATION_VCS_ID, \
-  LALSIMULATION_VCS_DATE, \
-  LALSIMULATION_VCS_BRANCH, \
-  LALSIMULATION_VCS_TAG, \
-  LALSIMULATION_VCS_AUTHOR, \
-  LALSIMULATION_VCS_COMMITTER, \
-  LALSIMULATION_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALSIMULATION_VCS_LINK_CHECK LALSIMULATION_CLEAN_9eb4cb215be628d8881a42e2ab467e3883ffba73_VCS_HEADER_LIBRARY_MISMATCH
+void LALSIMULATION_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalSimulationVCSInfoHeader = { \
 #endif /* _LALSIMULATIONVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
