@@ -222,7 +222,7 @@ static void Test_XLALSimIMRPhenomPCalculateModelParameters(void) {
   REAL8 f_ref = f_min;
   IMRPhenomP_version_type version = IMRPhenomPv2_V;
 
-  XLALSimIMRPhenomPCalculateModelParameters(
+  XLALSimIMRPhenomPCalculateModelParametersOld(
       &chi1_l,            /**< Output: aligned spin on companion 1 */
       &chi2_l,            /**< Output: aligned spin on companion 2 */
       &chip,              /**< Output: Effective spin in the orbital plane */
@@ -282,13 +282,12 @@ static void Test_PhenomC(void) {
   REAL8 phPhenomC = 0.0;
   REAL8 aPhenomC  = 0.0;
 
-  const LALSimInspiralTestGRParam *nonGR = NULL;
   BBHPhenomCParams *PCparams = ComputeIMRPhenomCParamsRDmod(
     m1,    /**< mass of companion 1 (solar masses) */
     m2,    /**< mass of companion 2 (solar masses) */
     chi,   /**< Reduced aligned spin of the binary chi = (m1*chi1 + m2*chi2)/M */
     chip, /**< Dimensionless spin in the orbial plane */
-    nonGR); /**< No testing GR parameters */
+    NULL); /**< No testing GR parameters */
 
   int errcode = IMRPhenomCGenerateAmpPhase( &aPhenomC, &phPhenomC, fHz, eta, PCparams );
   if( errcode != XLAL_SUCCESS )
@@ -419,10 +418,8 @@ static void Test_XLALSimIMRPhenomP(void) {
   REAL8 f_min = 20;
   REAL8 f_ref = f_min;
   IMRPhenomP_version_type version = IMRPhenomPv2_V;
-  const LALSimInspiralTestGRParam *nonGR = NULL;
 
-
-  XLALSimIMRPhenomPCalculateModelParameters(
+  XLALSimIMRPhenomPCalculateModelParametersOld(
       &chi1_l,            /**< Output: aligned spin on companion 1 */
       &chi2_l,            /**< Output: aligned spin on companion 2 */
       &chip,              /**< Output: Effective spin in the orbital plane */
@@ -466,7 +463,7 @@ static void Test_XLALSimIMRPhenomP(void) {
     f_max,                    /**< End frequency; 0 defaults to ringdown cutoff freq */
     f_ref,                    /**< Reference frequency */
     version,
-    nonGR);                   /**<linked list containing the extra testing GR parameters */
+    NULL);                   /**<linked list containing the extra testing GR parameters */
 
   dump_file("PhenomP_Test1.dat", hptilde, hctilde, m1+m2);
   MYUNUSED(ret);
@@ -644,10 +641,8 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
   REAL8 f_min = 20;
   REAL8 f_ref = f_min;
   IMRPhenomP_version_type version = IMRPhenomPv2_V;
-  const LALSimInspiralTestGRParam *nonGR = NULL;
 
-
-  XLALSimIMRPhenomPCalculateModelParameters(
+  XLALSimIMRPhenomPCalculateModelParametersOld(
       &chi1_l,            /**< Output: aligned spin on companion 1 */
       &chi2_l,            /**< Output: aligned spin on companion 2 */
       &chip,              /**< Output: Effective spin in the orbital plane */
@@ -691,7 +686,7 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
     f_max,                    /**< End frequency; 0 defaults to ringdown cutoff freq */
     f_ref,                    /**< Reference frequency */
     version,
-    nonGR);
+    NULL);
 
   dump_file("PhenomP_Test_f_ref1.dat", hptilde, hctilde, m1+m2);
   MYUNUSED(ret);
@@ -704,7 +699,7 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
   // Now repeat for a different f_ref
   f_ref = 5;
 
-  XLALSimIMRPhenomPCalculateModelParameters(
+  XLALSimIMRPhenomPCalculateModelParametersOld(
       &chi1_l,            /**< Output: aligned spin on companion 1 */
       &chi2_l,            /**< Output: aligned spin on companion 2 */
       &chip,              /**< Output: Effective spin in the orbital plane */
@@ -744,7 +739,7 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
     f_max,                    /**< End frequency; 0 defaults to ringdown cutoff freq */
     f_ref,                    /**< Reference frequency */
     version,
-    nonGR);
+    NULL);
 
 
   dump_file("PhenomP_Test_f_ref2.dat", hptilde2, hctilde2, m1+m2);
